==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/reef/dialogs_bg.lua <==
dialogId("uts-m-otresy", "font_small", "My goodness, the impact created cave-in!")
dialogStr("Божичко, ударът е бил доста силен!")

dialogId("uts-v-projet0", "font_big", "I can’t go through this cave-in, we have to find another exit.")
dialogStr("Не мога да се провра през отвора. Трябва да намерим друг изход.")

dialogId("uts-v-projet1", "font_big", "This is not the way.")
dialogStr("Не е това пътят.")

dialogId("uts-v-sam", "font_big", "I won’t make it alone.")
dialogStr("Сам няма да се справя.")

dialogId("uts-m-lastura", "font_small", "I probably should have had lifted that shell first.")
dialogStr("Май първо трябваше да вдигна онази черупка.")

dialogId("uts-v-poradi", "font_big", "Maybe we have to switch these objects.")
dialogStr("Може би трябва да разменим тези предмети.")

dialogId("uts-m-matrace", "font_small", "A mattress. The best thing you can get under water.")
dialogStr("Матрак! Най-доброто, което може да се намери под водата.")

dialogId("uts-m-snek", "font_small", "Now we can drop the snail on the mattress.")
dialogStr("Сега можем да пуснем охлювчето върху матрака.")

dialogId("uts-m-nezvedneme", "font_small", "It will be difficult to pick up that snail from there.")
dialogStr("Трудно ще е да вземем онзи охлюв оттам.")

dialogId("uts-v-konecne", "font_big", "Finally, it’s there.")
dialogStr("Най-сетне на място.")

dialogId("uts-m-chudak", "font_small", "The poor snail...")
dialogStr("Бедното охлювче...")

dialogId("uts-v-koraly", "font_big", "We should search the coral reefs.")
dialogStr("Трябва да претърсим кораловите рифове.")

dialogId("uts-m-tvorove", "font_small", "There are going to be many interesting beings to investigate there.")
dialogStr("Там ще има много интересни неща за изследване.")

dialogId("uts-v-mikroskop", "font_big", "Don’t we need a microscope to investigate corals?")
dialogStr("Не ни ли трябва микроскоп за изследване на коралите?")

dialogId("uts-m-zivocich", "font_small", "Yes, they are small. But there can be other life forms.")
dialogStr("Да, коралите са малки. Но там може да има и други форми на живот.")

dialogId("uts-m-zelvy", "font_small", "Coral turtles, for example.")
dialogStr("Коралови костенурки, например.")

dialogId("uts-m-batyskaf", "font_small", "And moreover I have a suspicion that there's a microscope in a bathyscaph.")
dialogStr("Освен това, подозирам, че в батискафа има микроскоп.")

==> fillets-ng-data_0.9.2.orig.tar.gz: fillets-ng-data-0.9.2/script/reef/dialogs_bg.lua <==
dialogId("uts-m-otresy", "font_small", "My goodness, the impact created cave-in!")
dialogStr("Божичко, ударът е бил доста силен!")

dialogId("uts-v-projet0", "font_big", "I can’t go through this cave-in, we have to find another exit.")
dialogStr("Не мога да се провра през отвора. Трябва да намерим друг изход.")

dialogId("uts-v-projet1", "font_big", "This is not the way.")
dialogStr("Не е това пътят.")

dialogId("uts-v-sam", "font_big", "I won’t make it alone.")
dialogStr("Сам няма да се справя.")

dialogId("uts-m-lastura", "font_small", "I probably should have had lifted that shell first.")
dialogStr("Май първо трябваше да вдигна онази черупка.")

dialogId("uts-v-poradi", "font_big", "Maybe we have to switch these objects.")
dialogStr("Може би трябва да разменим тези предмети.")

dialogId("uts-m-matrace", "font_small", "A mattress. The best thing you can get under water.")
dialogStr("Матрак! Най-доброто, което може да се намери под водата.")

dialogId("uts-m-snek", "font_small", "Now we can drop the snail on the mattress.")
dialogStr("Сега можем да пуснем охлювчето върху матрака.")

dialogId("uts-m-nezvedneme", "font_small", "It will be difficult to pick up that snail from there.")
dialogStr("Трудно ще е да вземем онзи охлюв оттам.")

dialogId("uts-v-konecne", "font_big", "Finally, it’s there.")
dialogStr("Най-сетне на място.")

dialogId("uts-m-chudak", "font_small", "The poor snail...")
dialogStr("Бедното охлювче...")

dialogId("uts-v-koraly", "font_big", "We should search the coral reefs.")
dialogStr("Трябва да претърсим кораловите рифове.")

dialogId("uts-m-tvorove", "font_small", "There are going to be many interesting beings to investigate there.")
dialogStr("Там ще има много интересни неща за изследване.")

dialogId("uts-v-mikroskop", "font_big", "Don’t we need a microscope to investigate corals?")
dialogStr("Не ни ли трябва микроскоп за изследване на коралите?")

dialogId("uts-m-zivocich", "font_small", "Yes, they are small. But there can be other life forms.")
dialogStr("Да, коралите са малки. Но там може да има и други форми на живот.")

dialogId("uts-m-zelvy", "font_small", "Coral turtles, for example.")
dialogStr("Коралови костенурки, например.")

dialogId("uts-m-batyskaf", "font_small", "And moreover I have a suspicion that there’s a microscope in a bathyscaph.")
dialogStr("Освен това, подозирам, че в батискафа има микроскоп.")
